# Generated by roxygen2: do not edit by hand

export(compare_file_object)
export(darwin_variant)
export(expect_snapshot_data)
export(expect_snapshot_object)
export(platform_variant)
export(save_csv)
export(save_deparse)
export(save_json)
export(save_rds)
export(system_os)
importFrom(dplyr,where)
